{% extends 'base.html' %}
{% load i18n %}
{% block title %}{% trans 'Alarm Definition Details' %}{% endblock %}

{% block page_header %}
  {% include "horizon/common/_page_header.html" with title="Alarm Definition Details" %}
{% endblock page_header %}

{% block main %}
    {% include 'monitoring/alarmdefs/_detail.html' %}
{% endblock %}
