{% extends 'base.html' %}
{% load i18n %}
{% block title %}{% trans 'Monitoring' %}{% endblock %}

{% block page_header %}
  {% include 'horizon/common/_page_header.html' with title="Monitoring" %}
{% endblock page_header %}
{% load url from future %}
{% block main %}
    <div style="padding: 3px;">
        <a href="{%  url 'horizon:monitoring:alarms:alarm' 'all'%}" class="btn btn-default btn-sm showspinner">{% trans 'All Alarms' %}</a>
        <a target="dashboard" href="/static/grafana/index.html#/dashboard/file/openstack.json?token={{ token }}" class="btn btn-default btn-sm">
            <span class="glyphicon glyphicon-dashboard"></span>
            {% trans 'Dashboard' %}
        </a>
    </div>
    {%  include 'monitoring/overview/monitor.html' %}
{% endblock %}
